@@ -11,13 +11,13 @@
 extern SEXP evaluateEffn(SEXP, SEXP, SEXP);
 extern SEXP miCalc(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP orientation(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP orientationProbability(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP skeleton(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP orientationProbability(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP skeleton(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"evaluateEffn",           (DL_FUNC) &evaluateEffn,            3},
-    {"orientationProbability", (DL_FUNC) &orientationProbability, 15},
-    {"skeleton",               (DL_FUNC) &skeleton,               15},
+    {"orientationProbability", (DL_FUNC) &orientationProbability, 13},
+    {"skeleton",               (DL_FUNC) &skeleton,               16},
     {NULL, NULL, 0}
 };
 
